@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12211 2020-05-13 13:11:29Z Andy $
+# $Id: __init__.py 12224 2020-05-15 09:54:33Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $ (last)
-# $Date: 2020-05-13 21:11:29 +0800 (週三, 13 五月 2020) $
-# $Revision: 12211 $
+# $Date: 2020-05-15 17:54:33 +0800 (週五, 15 五月 2020) $
+# $Revision: 12224 $
 
 import os
 import sys
@@ -104,7 +104,7 @@ def attachSettings(settingsDict):
         'django_gravatar',
         'captcha',
         'Zephyrus.map',
-        
+        'Zephyrus.seo',
     ]
     
     if ZEPHYRUS_BLOG_ENABLE:
@@ -122,7 +122,6 @@ def attachSettings(settingsDict):
             
             'django.contrib.redirects',
             'Zephyrus.blog_extension',
-            'Zephyrus.seo',
         ]
 
     if ZEPHYRUS_OSCAR_ENABLE:
@@ -307,17 +306,11 @@ def attachURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
-    from django.conf.urls import url, include
-
-    urlpatterns += patterns('',
-        url(r'^landing/', include('Zephyrus.landing.urls')),
-        url(r'^', include('Zephyrus.comment.urls')),
-        url(r'^', include('Zephyrus.facebook.urls')),
-    )
+    from Zephyrus import seo, facebook, comment, landing
     
-    from Zephyrus import seo
-    
-    seo.attachURLs(settings, urlpatterns)
-            
+    landing.attachURLs(settings, urlpatterns)
+    comment.attachURLs(settings, urlpatterns)
+    facebook.attachURLs(settings, urlpatterns)
+    seo.attachURLs(settings, urlpatterns) 
 
     
