@@ -67,13 +67,13 @@ from Zephyrus.landing import ErrorCode
 from Zephyrus.landing.models import Email
 from Zephyrus.blog_extension.models import CallToActionModel, CallToActionStatistics
 from Zephyrus.blog_extension import settings as _settings
-from Zephyrus.ZephyrusSettings import BASE_DIR as ZEPHYRUS_BASE_DIR
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler())
 
 PDF_ROOT = 'pdf/'
+CALL_TO_ACTION_BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
 
 def renderArticle(request, articleId):
@@ -136,14 +136,24 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, actionId, formId=None,
     data = f"{email}{actionId}"
     m.update(data.encode("utf-8"))
     token = m.hexdigest()
+    
+    # determine whether this plugin belongs to a article detail page
+    slug = fromUrl.split('/')[-2]
+    article = Article.objects.filter(translations__slug=slug)
+    if article.exists():
+        article = article[0]
+        pluginUrl = None
+    else:
+        article = None
+        pluginUrl = fromUrl
+        
     actionRecord, created = CallToActionStatistics.objects.get_or_create(
         action=action,
         email=email,
-        url=fromUrl,
-        defaults={'token':token, 'count':0}
+        url=pluginUrl,
+        article=article,
+        defaults={'token':token, 'count':0},
     )
-    # if not created:
-    #     actionRecord.count = actionRecord.count + 1
     actionRecord.save()
     
     website = Site.objects.get_current()
@@ -313,7 +323,7 @@ def showTargetFile(request):
     import sys
     # local windows use PE file in Zephyrus
     if sys.platform.startswith("win32"):
-        config = pdfkit.configuration(wkhtmltopdf=os.path.join(ZEPHYRUS_BASE_DIR, 'wkhtmltopdf.exe'))
+        config = pdfkit.configuration(wkhtmltopdf=os.path.join(CALL_TO_ACTION_BASE_DIR, 'assets', 'wkhtmltopdf.exe'))
     
     # on Linux, pdfkit complete configuration by which 
     else:
@@ -341,10 +351,8 @@ def showTargetFile(request):
             domain = Site.objects.get_current().domain
             websiteName = Site.objects.get_current().name
             
-            slug = callToActionStatistics.url.split('/')[-2]
-            article = Article.objects.filter(translations__slug=slug)
-            if article:
-                article = article[0]
+            if callToActionStatistics.article:
+                article = callToActionStatistics.article
                 articleId = int_to_hashid(article.pk)
                 fileName = f'[{websiteName}]{article.slug}.pdf'
                 path = settings.MEDIA_URL + PDF_ROOT + fileName
@@ -360,13 +368,14 @@ def showTargetFile(request):
                 # Warning: SSL error ignored
                 # Done but Exit with code 1 due to network error: RemoteHostClosedError
                 except Exception as e:
-                    pass
+                    logger.error('Not successfully transfer html to pdf: %s' % str(e))
 
 
             else:
             
                 # make PDF directly
                 
+                import requests
                 resp = requests.get(f"{settings.META_SITE_PROTOCOL}://{domain}{callToActionStatistics.url}")
                 soup = BeautifulSoup(resp.text, 'html.parser')
                 title = soup.find('title')
