@@ -21,6 +21,8 @@ from django.conf.urls import url
 from . import views
 
 urlpatterns = [
+    url(r"^auth/token/create/$", views.FacebookAccessTokenCreateView.as_view(), name='facebookAccessTokenCreate'),
+    url(r"^auth/token/return/$", views.FacebookAccessTokenReturnView.as_view(), name='facebookAccessTokenReturn'),
     url(r'^auth/redirect/$', views.AuthorizationRedirectView.as_view(), name='facebookAuthorizationRedirect'),
     url(r'^auth/$', 
         views.FacebookAuthorizationView.as_view(), name='facebookAuthorization')
