@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: LandingSocial.py 11861 2020-01-14 12:00:19Z Lavender $
+# $Id: LandingSocial.py 11892 2020-02-04 12:04:35Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,19 +12,14 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-01-14 20:00:19 +0800 (週二, 14 一月 2020) $
-# $Revision: 11861 $
+# $Date: 2020-02-04 20:04:35 +0800 (週二, 04 二月 2020) $
+# $Revision: 11892 $
 
 from django import template
 from django.utils.safestring import mark_safe
 from djangocms_forms.utils import int_to_hashid
 
-from Iuppiter.DjangoUtil import DJANGO_VERSION
-
-if DJANGO_VERSION <= 20000: # 2.0.0:
-    from django.core.urlresolvers import reverse
-else:
-    from django.urls import reverse
+from Iuppiter.DjangoUtil import DJANGO_VERSION, reverse
 
 register = template.Library()
 
